#
# spec file for package emacs-gnuplot-mode
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _sitedir %{_datadir}/emacs/site-lisp

Name:           emacs-gnuplot-mode
Version:        0.8.0
Release:        1.2
Summary:        Gnuplot mode for EMACS
License:        GPL-2.0-or-later
Group:          Productivity/Text/Editors
URL:            https://github.com/bruceravel/gnuplot-mode/tree/master
Source:         https://github.com/bruceravel/gnuplot-mode/archive/%{version}.tar.gz#/gnuplot-mode-%{version}.tar.gz
BuildRequires:  emacs-nox
BuildRequires:  texlive-latex
BuildRequires:  tex(fancybox.sty)
Requires:       emacs
Requires:       gnuplot
# Split-alias tag, gnuplot-mode was part of the gnuplot package
Provides:       gnuplot:%{_sitedir}/gnuplot.el
BuildArch:      noarch

%description
Gnuplot-mode is a major Emacs mode for editing Gnuplot source code. It
provides syntax highlighting, automatic indentation and context sensitive
command completion.

%package doc
Summary:        Documentation for EMACS Gnuplot mode

%description doc
This package contains the Gnuplot mode documentation in PDF format.

%prep
%setup -q -n gnuplot-%{version}

%build
make -f Makefile default
pdflatex gpelcard.tex

%install
install -pm 755 -d %{buildroot}%{_sitedir}
install -pm 644 gnuplot*.el %{buildroot}%{_sitedir}/
install -pm 644 gnuplot*.elc %{buildroot}%{_sitedir}/

%files
%license LICENSE
%doc README.org
%dir %{_sitedir}
%{_sitedir}/gnuplot*el
%{_sitedir}/gnuplot*elc

%files doc
%doc gpelcard.pdf

%changelog
* Tue Jun 11 2024 Dr. Werner Fink <werner@suse.de>
- Update to 0.8.0
  * Changed project license to GPLv3.
  * Greatly simplify the compilation process.
  * Fix deprecated calls to the cl library.
  * Deprecated XEmacs support. Bump minimal GNU Emacs version to 24.3.
  * Add a gnuplot-program-args variable for passing additional
  arguments to the gnuplot program binary.
  * The gnuplot-inline-image-mode can now take three values: nil,
  inline, dedicated.
  * Add the gnuplot-use-context-sensitive-completion configuration
  option.
  * Removed the gnuplot-bug-report function.
  * The provided gnuplot.info manual file has been updated for gnuplot
  version 5.2.6.
  * Add the gnuplot-program-args customization option to pass
  additional arguments to the gnuplot process.
  * Use syntax-proprietize-rules in gnuplot buffers.
  * gnuplot-context-sensitive-mode is now a normal minor mode.
  * Enable completion-at-point in gnuplot comint buffers.
  * Remove the unused dotemacs.el file.
  * comint-process-echoes is now buffer-local.
* Thu Mar 11 2021 Dr. Werner Fink <werner@suse.de>
- Make sure that Upstream source tar ball fits local copy
* Mon Nov 20 2017 stefan.bruens@rwth-aachen.de
- Initial separate package for gnuplot mode. The gnuplot mode
  was formerly distributed as part of the gnuplot package.
- Update from version 0.6.1 to version 0.7.0
  * Added context sensitive auto completion
